summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorEvgeny Fadeev <evgeny.fadeev@gmail.com>2010-06-13 02:01:05 -0400
committerEvgeny Fadeev <evgeny.fadeev@gmail.com>2010-06-13 02:01:05 -0400
commit53b95d7c80da1436ba6cf7657c9641e986dcdca7 (patch)
tree74a7703e782c7438cd6b663d6b6482623205514a
parent9e9f6b0a71fca40b7a118acb4db37e45609fb5b8 (diff)
downloadaskbot-53b95d7c80da1436ba6cf7657c9641e986dcdca7.tar.gz
askbot-53b95d7c80da1436ba6cf7657c9641e986dcdca7.tar.bz2
askbot-53b95d7c80da1436ba6cf7657c9641e986dcdca7.zip
reverted some renamings of forum to askbot
-rw-r--r--askbot/conf/email.py2
-rw-r--r--askbot/conf/flatpages.py6
-rw-r--r--askbot/conf/site_settings.py12
-rw-r--r--askbot/deps/django_authopenid/forms.py2
-rw-r--r--askbot/forms.py2
-rw-r--r--askbot/views/meta.py4
6 files changed, 14 insertions, 14 deletions
diff --git a/askbot/conf/email.py b/askbot/conf/email.py
index defe86b8..dd3e5bdc 100644
--- a/askbot/conf/email.py
+++ b/askbot/conf/email.py
@@ -32,7 +32,7 @@ settings.register(
'This option currently defines default frequency '
'of emailed updates in the following five categories: '
'questions asked by user, answered by user, individually '
- 'selected, entire askbot (per person tag filter applies) '
+ 'selected, entire forum (per person tag filter applies) '
'and posts mentioning the user and comment responses'
)
)
diff --git a/askbot/conf/flatpages.py b/askbot/conf/flatpages.py
index f53694f3..27e3e35d 100644
--- a/askbot/conf/flatpages.py
+++ b/askbot/conf/flatpages.py
@@ -1,5 +1,5 @@
"""
-Q&A askbot flatpages (about, etc.)
+Q&A forum flatpages (about, etc.)
"""
from askbot.conf.settings_wrapper import settings
from askbot.deps.livesettings import ConfigurationGroup, LongStringValue
@@ -14,7 +14,7 @@ settings.register(
LongStringValue(
FLATPAGES,
'FORUM_ABOUT',
- description=_('Text the Q&A askbot About page (html format)'),
+ description=_('Text of the Q&A forum About page (html format)'),
help_text=\
_(
'Save, then <a href="http://validator.w3.org/">'
@@ -27,7 +27,7 @@ settings.register(
LongStringValue(
FLATPAGES,
'FORUM_PRIVACY',
- description=_('Text the Q&A askbot Privacy Policy (html format)'),
+ description=_('Text of the Q&A forum Privacy Policy (html format)'),
help_text=\
_(
'Save, then <a href="http://validator.w3.org/">'
diff --git a/askbot/conf/site_settings.py b/askbot/conf/site_settings.py
index 8bd4590a..5b0213e4 100644
--- a/askbot/conf/site_settings.py
+++ b/askbot/conf/site_settings.py
@@ -10,7 +10,7 @@ from askbot import const
QA_SITE_SETTINGS = ConfigurationGroup(
'QA_SITE_SETTINGS',
- _('Q&A askbot website parameters and urls')
+ _('Q&A forum website parameters and urls')
)
settings.register(
@@ -18,7 +18,7 @@ settings.register(
QA_SITE_SETTINGS,
'APP_TITLE',
default=u'ASKBOT: Open Source Q&A Forum',
- description=_('Site title for the Q&A askbot')
+ description=_('Site title for the Q&A forum')
)
)
@@ -26,7 +26,7 @@ settings.register(
StringValue(
QA_SITE_SETTINGS,
'APP_KEYWORDS',
- default=u'ASKBOT,CNPROG,askbot,community',
+ default=u'ASKBOT,CNPROG,forum,community',
description=_('Comma separated list of Q&A site keywords')
)
)
@@ -44,7 +44,7 @@ settings.register(
StringValue(
QA_SITE_SETTINGS,
'APP_DESCRIPTION',
- default='Open source question and answer askbot written in Python and Django',
+ default='Open source question and answer forum written in Python and Django',
description=_('Site description for the search engines')
)
)
@@ -55,7 +55,7 @@ settings.register(
'APP_SHORT_NAME',
default=_('Askbot'),
hidden=True,
- description=_('Short name for your Q&A askbot')
+ description=_('Short name for your Q&A forum')
)
)
@@ -64,7 +64,7 @@ settings.register(
QA_SITE_SETTINGS,
'APP_URL',
default='http://askbot.org',
- description=_('Base URL for your Q&A askbot, must start with http or https'),
+ description=_('Base URL for your Q&A forum, must start with http or https'),
)
)
diff --git a/askbot/deps/django_authopenid/forms.py b/askbot/deps/django_authopenid/forms.py
index 8a997c2d..3585cf7c 100644
--- a/askbot/deps/django_authopenid/forms.py
+++ b/askbot/deps/django_authopenid/forms.py
@@ -132,7 +132,7 @@ class ClassicLoginForm(forms.Form):
openid_logins = user.userassociation_set.all()
if len(openid_logins) > 0:
- msg1 = _('Account with this name already exists on the askbot')
+ msg1 = _('Account with this name already exists on the forum')
msg2 = _('can\'t have two logins to the same account yet, sorry.')
error_list.append(msg1)
error_list.append(msg2)
diff --git a/askbot/forms.py b/askbot/forms.py
index dabb80b6..e4dfd03b 100644
--- a/askbot/forms.py
+++ b/askbot/forms.py
@@ -385,7 +385,7 @@ class EditUserEmailFeedsForm(forms.Form):
label=_('Individually selected')
)
all_questions = EmailFeedSettingField(
- label=_('Entire askbot (tag filtered)'),
+ label=_('Entire forum (tag filtered)'),
)
mentions_and_comments = EmailFeedSettingField(
diff --git a/askbot/views/meta.py b/askbot/views/meta.py
index 344ca9ea..564b11e6 100644
--- a/askbot/views/meta.py
+++ b/askbot/views/meta.py
@@ -32,7 +32,7 @@ def feedback(request):
data['message'] = form.cleaned_data['message']
data['name'] = form.cleaned_data.get('name',None)
message = render_to_response('feedback_email.txt',data,context_instance=RequestContext(request))
- mail_admins(_('Q&A askbot feedback'), message)
+ mail_admins(_('Q&A forum feedback'), message)
msg = _('Thanks for the feedback!')
request.user.message_set.create(message=msg)
return HttpResponseRedirect(get_next_url(request))
@@ -52,7 +52,7 @@ def logout(request):#refactor/change behavior?
#I guess rationale was to tell the user that s/he may be still logged in
#through their external login sytem and we'd want to remind them about it
#however it might be a little annoying
#why not just show a message: you are logged out of askbot, but
#if you really want to log out -> go to your openid provider
return render_to_response('logout.html', {
'view_name':'logout',
@@ -52,7 +52,7 @@ def logout(request):#refactor/change behavior?
#through their external login sytem and we'd want to remind them about it
#however it might be a little annoying
-#why not just show a message: you are logged out of askbot, but
+#why not just show a message: you are logged out of forum, but
#if you really want to log out -> go to your openid provider
return render_to_response('logout.html', {